/*
 * imdbsearch.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: 
 */

#include <vdr/plugin.h>
#include <vdr/osdbase.h>
#include <vdr/config.h>
#include <stdio.h>
#include <vdr/device.h>

static const char *VERSION        = "0.1.4";
static const char *DESCRIPTION    = "Searches the IMDb";
static const char *MAINMENUENTRY  = "IMDb-Search";
static const int MAX_INFO_LENGTH=50000;

// --- cImdbSearchDisplay --------------------------------------------------------
class cImdbSearchDisplay : public cOsdMenu {
private:
	char text[MAX_INFO_LENGTH];

public:
  cImdbSearchDisplay(void);
  virtual ~cImdbSearchDisplay();
  virtual void Display(void);
  virtual eOSState ProcessKey(eKeys Key);
  };



cImdbSearchDisplay::cImdbSearchDisplay()
:cOsdMenu(tr("IMDb-Info"))
{
	for(int i=0; i<MAX_INFO_LENGTH; i++)
	{
		text[i] = '\0';
	}
	
	char input[500];
	FILE* f;
	f = fopen("/tmp/moviedata", "r");
	int i=0;
	while(!feof(f) && i<MAX_INFO_LENGTH)
	{
		fgets(input, 500, f);
		i+=strlen(input);
		if (i<MAX_INFO_LENGTH)strcat(text,input);
	} 
	fclose(f);
}



cImdbSearchDisplay::~cImdbSearchDisplay()
{
}

void cImdbSearchDisplay::Display(void)
{
  cOsdMenu::Display();
  DisplayMenu()->SetText(text, false);
}

eOSState cImdbSearchDisplay::ProcessKey(eKeys Key)
{
  switch (Key) {
    case kUp|k_Repeat:
    case kUp:
    case kDown|k_Repeat:
    case kDown:
    case kLeft|k_Repeat:
    case kLeft:
    case kRight|k_Repeat:
    case kRight:
         DisplayMenu()->Scroll(NORMALKEY(Key) == kUp || NORMALKEY(Key) == kLeft, NORMALKEY(Key) == kLeft || NORMALKEY(Key) == kRight);
         return osContinue;
    default:
         break;
    }

  eOSState state = cOsdMenu::ProcessKey(Key);

  if (state == osUnknown) {
     switch (Key) {
       case kOk:
            return osBack;
       default:
            state = osContinue;
       }
     state = osContinue;
     }
  return state;
}
// --- cPluginImdbSearch --------------------------------------------------------

class cPluginImdbSearch : public cPlugin {
private:
  	const cEvent *Present;
	const cEvent **pArray;
	int currentEvent;
	const char *titlePresentInfo;
        char *command;
public:
  cPluginImdbSearch(void);
  virtual ~cPluginImdbSearch();
  virtual const char *Version(void) { return VERSION; }
  virtual const char *Description(void) { return DESCRIPTION; }
  virtual const char *CommandLineHelp(void);
  virtual bool ProcessArgs(int argc, char *argv[]);
  virtual bool Start(void);
  virtual void Housekeeping(void);
  virtual const char *MainMenuEntry(void) { return MAINMENUENTRY; }
  virtual cOsdObject *MainMenuAction(void);
  virtual cMenuSetupPage *SetupMenu(void);
  virtual bool SetupParse(const char *Name, const char *Value);
  virtual cString SVDRPCommand(const char *Command, const char *Option, int &ReplyCode);
  void GetTitle(void);
  };

static int CompareEventTime(const void *p1, const void *p2)
{
  return (int)((*(cEvent **)p1)->StartTime() - (*(cEvent **)p2)->StartTime());
}

cPluginImdbSearch::cPluginImdbSearch(void)
{
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
}

cPluginImdbSearch::~cPluginImdbSearch()
{
  // Clean up after yourself!
}

const char *cPluginImdbSearch::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return NULL;
}

bool cPluginImdbSearch::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  return true;
}

bool cPluginImdbSearch::Start(void)
{
  // Start any background activities the plugin shall perform.
  
  return true;
}

void cPluginImdbSearch::Housekeeping(void)
{
  // Perform any cleanup or other regular tasks.
}

cOsdObject *cPluginImdbSearch::MainMenuAction(void)
{
  // Perform the action when selected from the main VDR menu.
  GetTitle();
  asprintf(&command, "imdb-search.sh \"%s\"",titlePresentInfo);
  Skins.Message(mtStatus, tr("Checking IMDb..."));
  int i=system(command);
  if (i==0)
  {
	return new cImdbSearchDisplay();
  }
  else
  {
    Skins.Message(mtError, tr("No data found!"));
    return NULL;
  }
}

cMenuSetupPage *cPluginImdbSearch::SetupMenu(void)
{
  // Return a setup menu in case the plugin supports one.
  return NULL;
}

bool cPluginImdbSearch::SetupParse(const char *Name, const char *Value)
{
  // Parse your own setup parameters and store their values.
  return false;
}

cString cPluginImdbSearch::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
{
  return NULL;
}

void cPluginImdbSearch::GetTitle(void)
{
	cChannel *Channel =  Channels.GetByNumber(cDevice::PrimaryDevice()->CurrentChannel());


	cSchedulesLock SchedulesLock;
	const cSchedules *Schedules = cSchedules::Schedules(SchedulesLock);
	if (Schedules) {
		const cSchedule *Schedule = Schedules->GetSchedule(Channels.GetByNumber(Channel->Number())->GetChannelID());
		if (Schedule) {
		        // Get Present event
		        time_t now = time(NULL);
			int a=0;
		        int num = ( Schedule->Events() )->Count();
	            // Free previous Array
	            Present = NULL;
	            if (pArray) {
	              free(pArray);
	              pArray = NULL;
	            }
	            pArray = MALLOC(const cEvent *, num);
	            if (pArray) {
	              int numreal = 0;
	              for (int a = 0; a < num; a++) {
	                const cEvent *EventInfo = ( Schedule->Events() )->Get(a);
	                // if (EventInfo->GetTime() + EventInfo->GetDuration() > now)
	                    pArray[numreal++] = EventInfo;
	              }
	              qsort(pArray, numreal, sizeof(cEvent *), CompareEventTime);
	            }
	            // Find the current event
	            while ( (a < num) && ( (pArray[a])->StartTime() + (pArray[a])->Duration() < now ) ) {
	              a++;
	            }
	            currentEvent = a;
	            if (a<num) {
	              Present = pArray[currentEvent];
	            }
		}
	}
        if (Present) {
	        titlePresentInfo = Present->Title();
	}

}


VDRPLUGINCREATOR(cPluginImdbSearch); // Don't touch this!
